@@ -1,7 +1,7 @@
 # ----------------------------------------------------------------------------------------------------------
 #  Copyright 2000-2009 by Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2009/mm/dd, v3.001.000, package ASNMTAP::Asnmtap Object-Oriented Perl
+# 2009/mm/dd, v3.001.001, package ASNMTAP::Asnmtap Object-Oriented Perl
 # ----------------------------------------------------------------------------------------------------------
 
 package ASNMTAP::Asnmtap;
@@ -60,7 +60,7 @@ BEGIN {
 
   @ASNMTAP::Asnmtap::EXPORT_OK   = ( @{ $ASNMTAP::Asnmtap::EXPORT_TAGS{ALL} } );
 
-  $ASNMTAP::Asnmtap::VERSION     = do { my @r = (q$Revision: 3.001.000$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+  $ASNMTAP::Asnmtap::VERSION     = do { my @r = (q$Revision: 3.001.001$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 }
 
 # read config file  - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -121,7 +121,7 @@ our $CAPTUREOUTPUT   = ( exists $_config{IO}{CAPTUREOUTPUT} )   ? $_config{IO}{C
 our $CHATCOMMAND     = '/usr/sbin/chat';
 our $DIFFCOMMAND     = '/usr/bin/diff';
 our $KILLALLCOMMAND  = '/usr/bin/killall';
-our $PERLCOMMAND     = '/usr/bin/env perl';
+our $PERLCOMMAND     = '/usr/bin/perl';
 our $PPPDCOMMAND     = '/usr/sbin/pppd';
 our $ROUTECOMMAND    = '/sbin/route';
 our $RSYNCCOMMAND    = '/usr/bin/rsync';
